@@ -2,7 +2,7 @@
 from rich.table import Table
 
 from raindropiopy.cli import COLOR_TABLE_COLUMN_1, COLOR_TABLE_COLUMN_2
-from raindropiopy.cli.models.eventLoop import EventLoop
+from raindropiopy.cli.models.event_loop import EventLoop
 
 
 def process(el: EventLoop) -> None:
